@@ -193,6 +193,7 @@ def download_image(post_id, output_folder=".", name_pattern=__default_name_patte
     # Save the metadata in a seperate file
     if save_json:
         json_name = image_name_base + os.path.extsep + "json"
+        json_path = os.path.join(output_folder, json_name)
         print_if_true("    Saving metadata JSON...", use_messages)
         with open(json_name, "w") as f:
             json.dump(image_info, f, indent=4)
@@ -214,7 +215,7 @@ def parse_args(args):
     parser.add_argument("-i", "--post_id", dest="post_id", help="the ID of the e621 post", type=int, required=True, metavar="ID")
     parser.add_argument("-f", "--dl_folder", dest="dl_folder", help="the folder to download to", type=dir_path, default=".", metavar="FOLDER")
     parser.add_argument("-n", "--name_pattern", dest="name_pattern", help="the file name (no extention), Replacements: {m}=md5, {i}=post_id ", type=str, default=__default_name_pattern__, metavar="NAME")
-    parser.add_argument("-t", "--no_tags", dest="add_tags", help="don't save tags or metadata", action='store_false')
+    parser.add_argument("-t", "--no_tags", dest="add_tags", help="don't embedd tags or metadata", action='store_false')
     parser.add_argument("-j", "--save_json", dest="save_json", help="saves metadata in a seperate .json file in additon to other options", action='store_true')
     parser.add_argument("-a", "--authorization", dest="authorization", help="your e621 username and API key", type=str, default=None, metavar="USERNAME:API_KEY")
     parser.add_argument("-u", "--user_agent", dest="user_agent", help="manual override of the user agent string", type=str, default=__default_user_agent__, metavar="USERAGENT")
